## Version 0.1.0 (2024-04-04)

### Issues Closed

* [Issue 2](https://github.com/spyder-ide/langchain-provider/issues/2) - Release langchain-provider 0.1.0 ([PR 1](https://github.com/spyder-ide/langchain-provider/pull/1) by [@dalthviz](https://github.com/dalthviz))

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 1](https://github.com/spyder-ide/langchain-provider/pull/1) - Some missing things and general clean up before a release, by [@dalthviz](https://github.com/dalthviz) ([2](https://github.com/spyder-ide/langchain-provider/issues/2))

In this release 1 pull request was closed.
